@@ -23,5 +23,5 @@ const Application = imports.application;
 
 function start() {
     let application = new Application.Application();
-    return application.application.run(ARGV);
+    return application.run(ARGV);
 }
